# History

## 0.2.3 - 2020-09-20

- Update test environment and make test commands.

## 0.2.2 - 2020-02-12

- Add github actions and perform tests over the readme example.

## 0.2.1 - 2020-02-12

- Slight user API improvements.
- Removal of unused code.
- Improved documentation and tutorials.
- Setup to run GPE on a Docker container.

## 0.2.0 - 2020-02-06

First full release

- Data Preprocessing
- Prediction Engineering Framework
- First Labeling functions

## 0.1.0 - 2019-10-31

First Pre-Release
